@@ -4,11 +4,38 @@ use warnings;
 
 package Dist::Zilla::Plugin::PortabilityTests;
 BEGIN {
-  $Dist::Zilla::Plugin::PortabilityTests::VERSION = '1.101420';
+  $Dist::Zilla::Plugin::PortabilityTests::VERSION = '1.111840';
 }
 # ABSTRACT: Release tests for portability
 use Moose;
 extends 'Dist::Zilla::Plugin::InlineFiles';
+with 'Dist::Zilla::Role::FileMunger';
+
+has options => (
+  is      => 'ro',
+  isa     => 'Str',
+  default => '',
+);
+
+sub munge_file {
+  my ($self, $file) = @_;
+  return unless $file->name eq 'xt/release/portability.t';
+
+  # 'name => val, name=val'
+  my %options = split(/\W+/, $self->options);
+
+  if ( keys %options ) {
+    my $content = $file->content;
+
+    my $optstr = join ', ', map { "$_ => $options{$_}" } sort keys %options;
+
+    # insert options() above run_tests;
+    $content =~ s/^(run_tests\(\);)$/options($optstr);\n$1/m;
+
+    $file->content($content);
+  }
+  return;
+}
 
 __PACKAGE__->meta->make_immutable;
 no Moose;
@@ -19,19 +46,24 @@ no Moose;
 
 =pod
 
+=for test_synopsis 1;
+__END__
+
 =head1 NAME
 
 Dist::Zilla::Plugin::PortabilityTests - Release tests for portability
 
 =head1 VERSION
 
-version 1.101420
+version 1.111840
 
 =head1 SYNOPSIS
 
 In C<dist.ini>:
 
     [PortabilityTests]
+    ; you can optionally specify test options
+    options = test_dos_length = 1, use_file_find = 0
 
 =head1 DESCRIPTION
 
@@ -40,8 +72,16 @@ following file:
 
   xt/release/portability.t - a standard Test::Portability::Files test
 
-=for test_synopsis 1;
-__END__
+You can set options for the tests in the 'options' attribute:
+Specify C<< name = value >> separated by commas.
+
+See L<Test::Portability::Files/options> for possible options.
+
+=head1 METHODS
+
+=head2 munge_file
+
+Inserts the given options into the generated test file.
 
 =head1 INSTALLATION
 
@@ -58,17 +98,26 @@ L<http://rt.cpan.org/Public/Dist/Display.html?Name=Dist-Zilla-Plugin-Portability
 
 The latest version of this module is available from the Comprehensive Perl
 Archive Network (CPAN). Visit L<http://www.perl.com/CPAN/> to find a CPAN
-site near you, or see
-L<http://search.cpan.org/dist/Dist-Zilla-Plugin-PortabilityTests/>.
+site near you, or see L<http://search.cpan.org/dist/Dist-Zilla-Plugin-PortabilityTests/>.
 
-The development version lives at
-L<http://github.com/hanekomu/Dist-Zilla-Plugin-PortabilityTests/>.
-Instead of sending patches, please fork this project using the standard git
-and github infrastructure.
+The development version lives at L<http://github.com/hanekomu/Dist-Zilla-Plugin-PortabilityTests>
+and may be cloned from L<git://github.com/hanekomu/Dist-Zilla-Plugin-PortabilityTests.git>.
+Instead of sending patches, please fork this project using the standard
+git and github infrastructure.
 
-=head1 AUTHOR
+=head1 AUTHORS
 
-  Marcel Gruenauer <marcel@cpan.org>
+=over 4
+
+=item *
+
+Marcel Gruenauer <marcel@cpan.org>
+
+=item *
+
+Randy Stauner <rwstauner@cpan.org>
+
+=back
 
 =head1 COPYRIGHT AND LICENSE
 
